# -*- coding: utf-8 -*-

''' Configuración global.

    Variables de configuración que sirven a distintos propósitos y se importan
    desde diferentes módulos. '''

import os
import logging

SERVER_PORT = 10000
CLIENT_PORT = 10000

LOG_FORMAT = '%(asctime)s %(levelname)s %(message)s'

# 1. Global configuration values:
CONFIG_DIR = "/var/vaguada"
INTERFACE_CONFIG_DIR = os.sep + 'etc' + os.sep + 'vaguada'
SERVER_CONFIG_DIR = os.sep + 'etc' + os.sep + 'vaguada'
CONFIG_FILE = CONFIG_DIR + os.sep + 'config.xml'

# 2. Configuración de la interfaz de usuario:
GUI_CONFIG_FILE = INTERFACE_CONFIG_DIR + os.sep + 'interface.vaguada'
DEFAULT_INTERFACE_CONFIGURATION = {'labels':  False,
                                   'refresh': 10,
                                   'font':    10}
BIG_VALUE = 200000
LOG_TAIL_LENGTH = 100
LIST_OF_CENTRES_FILE_NAME = INTERFACE_CONFIG_DIR + os.sep + 'centres.vaguada'
INE_CODES_FILE = INTERFACE_CONFIG_DIR + os.sep + 'ine_codes.vaguada'
PACKAGES_FILE = INTERFACE_CONFIG_DIR + os.sep + 'packages.vaguada'
STATIC_CONF_FILE = INTERFACE_CONFIG_DIR + os.sep + 'static_conf.vaguada'
BACKUP_FILES = INTERFACE_CONFIG_DIR + os.sep + 'files.vaguada'

# 3. Low level data:
GLADE_FILE_NAME = 'common/gui/vaguada.glade'
ICON_PREFIX = 'common/gui/pixmaps/'
APP_ICON_FILE = ICON_PREFIX + 'app.png'
CONNECTED_ICON_FILE = ICON_PREFIX + 'connected.png'
DISCONNECTED_ICON_FILE = ICON_PREFIX + 'disconnect.png'
WARNING_ICON_FILE = ICON_PREFIX + 'warning.png'
IMPORT_ICON_FILE = ICON_PREFIX + 'open.png'
EXPORT_ICON_FILE = ICON_PREFIX + 'save.png'
EDIT_ICON_FILE = ICON_PREFIX + 'edit.png'
CONFIG_ICON_FILE = ICON_PREFIX + 'config.png'
ABOUT_ICON_FILE = ICON_PREFIX + 'about.png'
HISTORY_ICON_FILE = ICON_PREFIX + 'history.png'
BUTTON_LABELS = ('labelSesion', 'labelActualizar', 'labelContraer',
                 'labelExpandir', 'labelConectados', 'labelProblematicos', 'labelRegistros')

TIME_ICON_FILE = ICON_PREFIX +       'time.png'      # TimeIncidence
ID_ICON_FILE = ICON_PREFIX +         'id.png'        # CentreCodeIncidence
SYNC_ICON_FILE = ICON_PREFIX +       'sync.png'      # SyncIncidence
UPDATE_ICON_FILE = ICON_PREFIX +     'update.png'    # UpdateIncidence
LOG_ICON_FILE = ICON_PREFIX +        'log.png'       # BadLogIncidence
PROCESS_ICON_FILE = ICON_PREFIX +    'process.png'   # ParseIncidence
CALENDAR_ICON_FILE = ICON_PREFIX +   'calendar.png'  # DelayedIncidence
IP_CHANGED_ICON_FILE = ICON_PREFIX + 'address.png'   # IpChangedIncidence
INCIDENCE_ICON_FILE = ICON_PREFIX +  'incidence.png' # DummyIncidence, Incidence

# 4. Names of "widgets":
WIDGET_MAIN = 'mainWindow'
WIDGET_ABOUT = 'aboutDialog'
WIDGET_FILE = 'fileDialog'
WIDGET_CONFIG = 'configurationDialog'
WIDGET_EDITION = 'editionDialog'

# 5. Data about the software:
APP_NAME = 'Vaguada'
APP_VERSION = '0.9'
APP_AUTHORS = ['Sociedad andaluza para el desarrollo de la sociedad de la información', \
               'Junta de Andalucía']
APP_DESCRIPTION = ''
APP_COPYRIGHT = '© 2006 Junta de Andalucía'
APP_URL = ''
APP_URL_LABEL = ''

# 6. Status bar "contexts":
STATUS_BAR_ONLY_CONTEXT = 0
# CONTEXT_DEFAULT = 0
# CONTEXT_INIT = 1

# 7. Logging levels:
LOG_CRITICAL = 0
LOG_ERROR = 1
LOG_WARNING = 2
LOG_DEBUG = 3

# 8. Available "roles" for the software:
ACT_AS_SERVER = -1

# 9. TODO. Temporarily:
PROVINCES = (( 4, 'Almería'),
             (11, 'Cádiz'),
             (14, 'Córdoba'),
             (18, 'Granada'),
             (21, 'Huelva'),
             (23, 'Jaén'),
             (29, 'Málaga'),
             (41, 'Sevilla'))

# Fin del archivo.

