#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Definición de las interfaces comunes a los clientes y
a los servidores.
"""

class IUIAssistant:
    """
    Interfaz que define los métodos necesarios para la obtención de los datos
    por parte de la interfaz gráfica de usuario. 

    Esta interfaz es usada por ambas interfaces de usuario (la del servidor y la
    del cliente) para obtener datos de sus respectivos demonios. 

    Estos datos engloban todo lo referente a:

        - Incidencias.
        - Solución de incidencias.
        - Registros.
    """

    def __init__(self):
        raise NotImplementedError


    def get_incidences(self, center_code):
        """
        Método que se utiliza para obtener un listado de las incidencias de un
        centro determinado.

        @type center_code: tuple 
        @param center_code: Este parámetro indica el código del centro sobre el
        que se quiere obtener las incidencias. Los elementos son, en este orde,
        código de provincia, código de centro.

        @rtype: L{list}
        @return: lista de objetos L{common.incidences.IncidenceData} conteniendo la información
                 sobre todas las incidencias actualmente presentes en ese centro. """

        raise NotImplementedError

    def solve_incidence(self, incidence, method_pos, *params):
        """
        Método utilizado para resolver una incidencia.         

        @type incidence: IncidenceData 
        @param incidence: datos de la incidencia a resolver
        
        @type method_pos: int
        @param method_pos: opción escogida por el usuario para resolver la
        incidencia. Indica la posición de la opción escogida en la lista de
        opciones presentada por el método get_incidences.
        
        @type params: variable
        @param params: parámetros opcionales dependientes del tipo de
        incidencia que se vaya a resolver.
        """
        raise NotImplementedError


    def get_inc_log(self, center_code, lines = None):
        """
        Método que se utiliza para obtener una bitácora de incidencias sufridas
        por un centro.

        @type center_code: tuple
        @param center_code: Tupla que identifica unequívocamente a un centro.
        Tiene dos elementos: el primero, el código de provincia, y el segundo,
        el código del centro.

        @type lines: int
        @param lines: Número de lineas (del final del fichero) que se deben
        devolver. Por defecto (lines = None) se devuelve el fichero completo

        @rtype: string
        @return: Contenido del log de incidencias para el centro seleccionado.
        """
        raise NotImplementedError


    def get_sync_log(self, center_code, lines = None):
        """
        Método usado para obtener una bitácora con los envíos realizados por un
        determinado centro.

        @type center_code: tuple
        @param center_code: Identificador del centro.

        @rtype: string
        @return: Contenido del log de envíos realizados para el centro

        @type lines: int
        @param lines: Número de lineas (del final del fichero) que se deben
        devolver. Por defecto (lines = None) se devuelve el fichero completo
        seleccionado. 
        """
        raise NotImplementedError



class IDataManager:
    """
    Esta interfaz engloba toda la lógica de envío de datos entre los clientes y
    el servidor y viceversa.
    """
    pass

